@@ -518,7 +518,7 @@ class VarDelayFloat:
 		return first_out
 
 @numba.jit
-def daqFilterEmulator(waveform, rise, top, tau, scaleFactor, threshold):
+def daqFilterEmulator(waveform, rise, top, tau, scaleFactor):
 	'''
 	This function emulates the DAQ filtering for the given input waveform and parameters.
 	
