@@ -485,9 +485,9 @@ def verifyDataIntegrity(initialFile, finalFile):
 		del out
 		gc.collect()
 		#now read in the waveform data and verify the checksums all match what they should
-		for key in testIn['waveforms']:
-			headers = testIn['waveforms/'+str(key)+'/headers'][()]
-			waveforms = testIn['waveforms/'+str(key)+'/waveforms'][()]
+		for key in testOut['waveforms']:
+			headers = testOut['waveforms/'+str(key)+'/headers'][()]
+			waveforms = testOut['waveforms/'+str(key)+'/waveforms'][()]
 			#check if these datasets are empty or not
 			if headers.shape is not None:
 				#if they have stuff, calculate the checksums and verify it all matches
